@@ -3,11 +3,14 @@ Created on 14.4.2012
 
 @author: xaralis
 '''
+
 from django.conf import settings
 
 ROOT_SITEMAP = settings.STATICSITEMAPS_ROOT_SITEMAP
 ROOT_DIR = getattr(settings, 'STATICSITEMAPS_ROOT_DIR', settings.STATIC_ROOT)
 USE_GZIP = getattr(settings, 'STATICSITEMAPS_USE_GZIP', True)
+GZIP_METHOD = getattr(settings, 'STATICSITEMAPS_GZIP_METHOD', 'python')  # must be in ['python', 'system', ]
+SYSTEM_GZIP_PATH = getattr(settings, 'STATICSITEMAPS_SYSTEM_GZIP_PATH', '/usr/bin/gzip')
 FILENAME_TEMPLATE = getattr(settings,
                             'STATICSITEMAPS_FILENAME_TEMPLATE',
                             'sitemap-%(section)s-%(page)s.xml')
